@@ -15,10 +15,10 @@ from pprint import pformat
 from sys import stdout
 from typing import TextIO, Tuple, Optional, Dict, List, Union, Any
 
-from console_debugger.helpful.coloring_text import style_t, StyleText
-from console_debugger.helpful.date_obj import ServerError
-from console_debugger.helpful.template_obj import *
-from console_debugger.logic.mg_send_socket import MgSendSocket
+from helpful.coloring_text import style_t, StyleText
+from helpful.date_obj import ServerError
+from template_obj import *
+from logic.mg_send_socket import MgSendSocket
 
 
 class Debugger:
